@@ -107,12 +107,12 @@ model_consistent <- function(seminr_model) {
   # if(!is.null(seminr_model$mobi_xm) && ("C" %in% seminr_model$mmMatrix[,"type"])) {
   #   cat("Models with interactions cannot be estimated as PLS consistent and therefore no adjustment for PLS consistent has been made\n")
   # }
-  if(!is.null(seminr_model$mobi_xm) && ("C" %in% seminr_model$mmMatrix[,"type"])) {
+  if(!is.null(seminr_model$interactions) && ("C" %in% seminr_model$mmMatrix[,"type"])) {
     cat("Models with interactions can be estimated as PLS consistent, but are subject to some bias as per Becker et al. (2018)
         'Estimating Moderating Effects in PLS-SEM and PLSc-SEM: Interaction Term Generation*Data Treatment'\n")
     seminr_model <- PLSc(seminr_model)
   }
-  if(is.null(seminr_model$mobi_xm) && ("C" %in% seminr_model$mmMatrix[,"type"])) {
+  if(is.null(seminr_model$interactions) && ("C" %in% seminr_model$mmMatrix[,"type"])) {
     seminr_model <- PLSc(seminr_model)
   }
   return(seminr_model)
